@@ -1,41 +1,49 @@
 import os
-import diagnostics
+import logging 
 
-def create_directory_if_not_exists(path):
-    log = diagnostics.StreamLogger()
+def create_directory_if_not_exists(path, level=logging.DEBUG):
+    logger = logging.getLogger("logger")
+    logger.setLevel(level)
+    logger.addHandler(logging.StreamHandler())
 
     exists = os.path.isdir(path)
     if not exists:
-        log.debug(path, " does not exist, creating ...")
+        logger.debug(path, " does not exist, creating ...")
         os.makedirs(path) 
 
-def get_git_directory():
-    log = diagnostics.StreamLogger()
+def get_git_directory(level=logging.DEBUG):
+    logger = logging.getLogger("logger")
+    logger.setLevel(level)
+    logger.addHandler(logging.StreamHandler())
 
-    log.debug("Looking for git directory ... ")
+    logger.debug("Looking for git directory ... ")
     current_working_directory = os.path.normpath(os.getcwd())
     git_directory_name = '.git'
-    git_directory = __find_folder_in_current_or_above(git_directory_name, current_working_directory)
+    git_directory = __find_folder_in_current_or_above(git_directory_name, current_working_directory, level)
 
-    log.info("Git directory found: " + git_directory)
+    logger.info("Git directory found: " + git_directory)
     return git_directory
 
-def get_root_directory():
-    log = diagnostics.StreamLogger()
+def get_root_directory(level=logging.DEBUG):
+    logger = logging.getLogger("logger")
+    logger.setLevel(level)
+    logger.addHandler(logging.StreamHandler())
 
-    log.debug("Looking for root directory ... ( dependant on the git directory )")
+    logger.debug("Looking for root directory ... ( dependant on the git directory )")
     root_directory = os.path.normpath(os.path.join(get_git_directory(), os.pardir))
 
-    log.info("Root directory found: " + root_directory)
+    logger.info("Root directory found: " + root_directory)
     return root_directory
 
-def __find_folder_in_current_or_above(dirname, currentdir):
-    log = diagnostics.StreamLogger()
+def __find_folder_in_current_or_above(dirname, currentdir, level=logging.DEBUG):
+    logger = logging.getLogger("logger")
+    logger.setLevel(level)
+    logger.addHandler(logging.StreamHandler())
 
     while_counter = 0
     max_while_counter = 100
     
-    log.debug("Looking for " + dirname)
+    logger.debug("Looking for " + dirname)
     
     dirname_target = ""
     active_directory = currentdir
@@ -55,8 +63,8 @@ def __find_folder_in_current_or_above(dirname, currentdir):
             active_directory = os.path.normpath(active_directory)
             
             if active_directory == prev_active_directory:
-                log.error("\t\tWe reached the root of our directory")
-                log.error("\t\tCould not find directory " + dirname)
+                logger.error("\t\tWe reached the root of our directory")
+                logger.error("\t\tCould not find directory " + dirname)
                 break
 
             continue
@@ -65,13 +73,9 @@ def __find_folder_in_current_or_above(dirname, currentdir):
         dirname_target = os.path.normpath(dirname_target)
     
     if dirname_target == "":
-        log.error("\t\tCould not find directory " + dirname +". Max iterations reached(=100)")
+        logger.error("\t\tCould not find directory " + dirname +". Max iterations reached(=100)")
 
     return dirname_target
 
 def __get_subfolders(dirname):
-    return [f.path for f in os.scandir(dirname) if f.is_dir()]
-
-if __name__ == "__main__":
-    log = diagnostics.StreamLogger()
-    log.info(get_git_directory())
\ No newline at end of file
+    return [f.path for f in os.scandir(dirname) if f.is_dir()]
\ No newline at end of file
