@@ -1,5 +1,6 @@
+import os
 import platform
-import diagnostics
+import logging
 
 def get_python_command():
     python_command = ""
@@ -19,17 +20,20 @@ def get_shell_extension():
 
     return extension
 
-def evaluate_statuscode(statusCode):
-    log = diagnostics.StreamLogger()
+def evaluate_statuscode(statusCode, level=logging.DEBUG):
+    logger = logging.getLogger("logger")
+    logger.setLevel(level)
+    logger.addHandler(logging.StreamHandler())
+
     if platform.system().lower() == "windows":
-        log.debug("Status Code:" + str(statusCode))
+        logger.debug("Status Code:" + str(statusCode))
         if statusCode != 0:
-            log.error("Error Code:" + str(statusCode))
+            logger.error("Error Code:" + str(statusCode))
             return False
     else:
-        log.debug("Status Code:" + str(statusCode))
+        logger.debug("Status Code:" + str(statusCode))
         if not os.WIFEXITED(statusCode):
-            log.error("Error Code: " + os.WEXITSTATUS(statusCode))
+            logger.error("Error Code: " + os.WEXITSTATUS(statusCode))
             return False
     
     return True
\ No newline at end of file
